@@ -99,7 +99,6 @@ tpro_start(
 	 * Initialize miscellaneous peer variables
 	 */
 	peer->precision = PRECISION;
-	peer->burst = NSTAGE;
 	pp->clockdesc = DESCRIPTION;
 	memcpy((char *)&pp->refid, REFID, 4);
 	return (1);
@@ -195,8 +194,6 @@ tpro_poll(
 		refclock_report(peer, CEVNT_BADTIME);
 		return;
 	}
-	if (peer->burst > 0)
-		return;
 	if (pp->coderecv == pp->codeproc) {
 		refclock_report(peer, CEVNT_TIMEOUT);
 		return;
@@ -204,9 +201,8 @@ tpro_poll(
 	pp->lastref = pp->lastrec;
 	record_clock_stats(&peer->srcadr, pp->a_lastcode);
 	refclock_receive(peer);
-	peer->burst = NSTAGE;
 }
 
 #else
-int refclock_tpro_bs;
+NONEMPTY_TRANSLATION_UNIT
 #endif /* REFCLOCK */
